@@ -130,7 +130,7 @@ class NumberBox (Gtk.DrawingArea):
         self.bottom_note_list = []
         self.tinfo = tracker_info.TrackerInfo()
         self.set_property('can-focus', True)
-        self.set_property('events', Gdk.EventMask.ALL_EVENTS_MASK)
+        self.add_events(Gdk.EventMask.ALL_EVENTS_MASK)
         self.connect('button-press-event', self.button_press_cb)
         self.connect('key-release-event', self.key_press_cb)
         self.connect('enter-notify-event', self.pointer_enter_cb)
@@ -695,7 +695,7 @@ class NumberBox (Gtk.DrawingArea):
         pass
 
     def set_value (self, v):
-        if 0 < v <= self.upper:
+        if v != None and 0 < v <= self.upper:
             self.set_text(str(v))
         else:
             self.set_text('')
